@@ -5,7 +5,7 @@ from django.http import HttpRequest
 from ridi_django_oauth2.config import RidiOAuth2Config
 from ridi_oauth2.client.dtos import TokenData
 from ridi_oauth2.introspector.dtos import AccessTokenInfo
-from ridi_oauth2.introspector.exceptions import ExpireTokenException, InvalidJwtSignatureException
+from ridi_oauth2.introspector.exceptions import ExpireTokenException, InvalidJwtSignatureException, InvalidToken
 from ridi_oauth2.introspector.helpers import JwtIntrospectHelper
 
 
@@ -17,11 +17,12 @@ def get_token_from_cookie(request: HttpRequest) -> TokenData:
 
 
 def get_token_info(token: str) -> typing.Optional[AccessTokenInfo]:
+    token_info = None
     try:
-        token_info = JwtIntrospectHelper.introspect(jwt_info=RidiOAuth2Config.get_jwt_info(), access_token=token)
-    except (KeyError, ExpireTokenException, InvalidJwtSignatureException):
-        token_info = None
+        token_info = JwtIntrospectHelper.introspect(token)
 
+    except (KeyError, ExpireTokenException, InvalidJwtSignatureException, InvalidToken):
+        pass
     return token_info
 
 
